@@ -23,13 +23,13 @@ __all__ = ['ChannelInputFile',
            'TrapezoidalCS']
 
 from future.utils import iteritems
-import xml.etree.ElementTree as ET
+import logging
 import json
-
+from mapkit.sqlatypes import Geometry
 from sqlalchemy import ForeignKey, Column
 from sqlalchemy.types import Integer, String, Float, Boolean
 from sqlalchemy.orm import relationship
-from mapkit.sqlatypes import Geometry
+import xml.etree.ElementTree as ET
 
 from . import DeclarativeBase
 from ..base.geom import GeometricObjectBase
@@ -37,6 +37,9 @@ from ..base.file_base import GsshaPyFileObjectBase
 from ..lib import parsetools as pt, cif_chunk as cic
 from ..lib.parsetools import valueReadPreprocessor as vrp, valueWritePreprocessor as vwp
 
+log = logging.getLogger(__name__)
+
+
 class ChannelInputFile(DeclarativeBase, GsshaPyFileObjectBase):
     """
     Object interface for the Channel Input File.
@@ -157,7 +160,7 @@ class ChannelInputFile(DeclarativeBase, GsshaPyFileObjectBase):
 
         if 'lineColor' in styles:
             if len(styles['lineColor']) < 4:
-                print('WARNING: lineColor style must be a list or a tuple of four elements containing integer RGBA values.')
+                log.warn('lineColor style must be a list or a tuple of four elements containing integer RGBA values.')
             else:
                 userLineColor = styles['lineColor']
                 lineColorValue = (userLineColor[3], userLineColor[2], userLineColor[1], userLineColor[0])
@@ -168,7 +171,7 @@ class ChannelInputFile(DeclarativeBase, GsshaPyFileObjectBase):
                 lineWidthValue = styles['lineWidth']
 
             except ValueError:
-                print('WARNING: lineWidth must be a valid number containing the width of the line in pixels.')
+                log.warn('lineWidth must be a valid number containing the width of the line in pixels.')
 
         if 'nodeIconHref' in styles:
             nodeIconHrefValue = styles['nodeIconHref']
@@ -179,7 +182,7 @@ class ChannelInputFile(DeclarativeBase, GsshaPyFileObjectBase):
                 nodeIconScaleValue = styles['nodeIconScale']
 
             except ValueError:
-                print('WARNING: nodeIconScaleValue must be a valid number containing the width of the line in pixels.')
+                log.warn('nodeIconScaleValue must be a valid number containing the width of the line in pixels.')
 
 
         # Initialize KML Document
@@ -209,7 +212,7 @@ class ChannelInputFile(DeclarativeBase, GsshaPyFileObjectBase):
                 lineString = ET.fromstring(linkKML)
                 placemark.append(lineString)
             else:
-                print("WARNING: No geometry found for link with id {0}".format(link.id))
+                log.warn("No geometry found for link with id {0}".format(link.id))
 
             if withNodes:
                 # Create the node styles
@@ -785,7 +788,7 @@ class ChannelInputFile(DeclarativeBase, GsshaPyFileObjectBase):
                 self._writeReservoirLink(link, fileObject, replaceParamFile)
 
             else:
-                print('OOPS: CIF LINE 417')  # THIS SHOULDN'T HAPPEN
+                log.error('OOPS: CIF LINE 417')  # THIS SHOULDN'T HAPPEN
 
             fileObject.write('\n')
 
@@ -1078,7 +1081,7 @@ class ChannelInputFile(DeclarativeBase, GsshaPyFileObjectBase):
                     for bp in xSec.breakpoints:
                         fileObject.write('X1   %.6f %.6f\n' % (bp.x, bp.y))
                 else:
-                    print('OOPS: MISSED A CROSS SECTION TYPE. CIF LINE 580. {0}'.format(linkType))
+                    log.error('OOPS: MISSED A CROSS SECTION TYPE. CIF LINE 580. {0}'.format(linkType))
 
     def _writeOptionalXsecCards(self, fileObject, xSec, replaceParamFile):
         """
