@@ -10,6 +10,8 @@
 
 # This file is purely for convenience
 from .cmt import MapTableFile
+from .ele import ElevationGridFile
+from .evt import ProjectFileEventManager
 from .gag import PrecipFile
 from .cif import ChannelInputFile
 from .spn import StormPipeNetworkFile
@@ -20,6 +22,7 @@ from .gst import GridStreamFile
 from .tim import TimeSeriesFile
 from .loc import OutputLocationFile
 from .map import RasterMapFile
+from .msk import WatershedMaskFile
 from .pro import ProjectionFile
 from .rep import ReplaceParamFile, ReplaceValFile
 from .lnd import LinkNodeDatasetFile
